@@ -1,6 +1,6 @@
 #!perl -w
 #
-# $Id: exe_wrap.pl,v 1.85 2010/04/19 04:52:12 rmeden Exp $
+# $Id: exe_wrap.pl,v 1.88 2010/11/22 06:04:58 rmeden Exp $
 # This is a quick XMLTV shell routing to use with the windows exe
 #
 # A single EXE is needed to allow sharing of modules and dlls of all the
@@ -69,7 +69,7 @@ print STDERR "Timezone is $ENV{TZ}\n" unless $opt_quiet;
 $cmd = shift || "";
 
 # --version (and abbreviations thereof)
-my $VERSION = '0.5.57';
+my $VERSION = '0.5.59';
 if (index('--version', $cmd) == 0 and length $cmd >= 3) {
     print "xmltv $VERSION\n";
     exit;
@@ -78,7 +78,7 @@ if (index('--version', $cmd) == 0 and length $cmd >= 3) {
 #
 # some grabbers aren't included
 #
-if ($cmd =~ /^tv_grab_(?:nz|jp|epgdata)$/) {
+if ($cmd =~ /^tv_grab_(eu_epgdata)$/) {
     die <<END
 Sorry, $cmd is not available in this Windows binary release, although
 it is included in xmltv source releases.
@@ -137,6 +137,7 @@ foreach my $exe (split(/ /,$files))
     next unless length($exe)>3; #ignore trash
     $_=$exe;
     s!^.+/!!g;
+    next if /epgdata/;
     $cmds{$_}=1;  # build command list (just in case)
 
     next unless $cmd eq $_;
